import { ref, nextTick } from 'vue';

const printUrl =
  'http://10.10.9.227:8080/webroot/help/page_demo/print_batch1.html';

export function usePrint(src = printUrl) {
  const iframeRef = ref<HTMLIFrameElement | null>(null);

  // 初始化 iframe
  const initializeIframe = () => {
    if (!iframeRef.value) {
      const iframe = document.createElement('iframe');
      iframe.id = 'printFrame';
      iframe.hidden = true;
      iframe.width = '0';
      iframe.height = '0';
      iframe.src = src;
      document.body.appendChild(iframe);
      iframeRef.value = iframe;
    }
  };
  initializeIframe();

  // 格式化打印数据
  const formatPrintData = (data: any[]) => {
    return data.map((item) => JSON.stringify({ ...item, deptCode: '' }));
  };

  // 发送打印数据
  const postPrintData = async (data: any[]) => {
    const formattedData = formatPrintData(data);

    // 等待 iframe 加载完成并发送消息
    await nextTick(() => {
      const iframeWindow = iframeRef.value?.contentWindow;
      if (iframeWindow) {
        iframeWindow.postMessage(formattedData, '*');
      }
    });
  };

  // 触发打印操作
  const triggerPrint = async (printData: any[]) => {
    if (printData.length > 0) {
      await postPrintData(printData);
    }
  };

  return {
    triggerPrint
  };
}
