/**
 * 路由配置
 */
import NProgress from 'nprogress';
import type { _RouteLocationBase } from 'vue-router';
import { createRouter, createWebHistory } from 'vue-router';
import { REDIRECT_PATH } from '@/config/setting';
import { useUserStore } from '@/store/modules/user';
import { setPageTitle } from '@/utils/page-title-util';
import { getRouteTitle } from '@/i18n/use-locale';
import { routes, getMenuRoutes } from './routes';
import { getAppInfo, getUserInfo } from '@/utils/token-util';
import { APPID } from '@/config/setting';
import { EleMessage } from 'ele-admin-plus';
import { useBackIndex } from '@fancy-design/tools';
import { useDepartment } from '@/store/modules/department';
import { getAppsDepartmentDataRequest } from '@/api/common/deptList';

NProgress.configure({
  speed: 200,
  minimum: 0.02,
  trickleSpeed: 200,
  showSpinner: false
});

const router = createRouter({
  routes,
  history: createWebHistory('bi'),
  scrollBehavior: () => {
    return { top: 0 };
  }
});

const _Dev = import.meta.env.DEV;
const _Pro = import.meta.env.PROD;
const _Preview = import.meta.env.VITE_PREVIEW === 'true';

/**
 * 路由守卫
 */
router.beforeEach(async (to) => {
  const userInfo = getUserInfo();
  const appId = APPID;

  if (!appId) {
    if (_Pro) {
      EleMessage.error('应用标识丢失,请重新进入应用!');
      useBackIndex();
    }
  }
  // 判断有无用户信息
  if (!userInfo) {
    // 本地启动,模拟登录
    if (_Dev || _Preview) {
      // await mockLogin(appId!);
    } else {
      debugger;
      useBackIndex();
    }
  }

  if (!to.path.includes(REDIRECT_PATH)) {
    NProgress.start();
    setPageTitle(getRouteTitle(to));
  }

  const { department, setDepartment } = useDepartment();

  // 获取科室数据
  if (!department.length) {
    const { code, data } = await getAppsDepartmentDataRequest({
      appId: appId!
    });
    if (code === 200) {
      setDepartment(data);
    }
  }

  // 注册动态路由
  const userStore = useUserStore();
  if (!userStore.menus) {
    const { menus, homePath } = await userStore.fetchUserInfo();
    if (menus) {
      getMenuRoutes(menus, homePath).forEach((r) => {
        router.addRoute(r);
      });
      return { ...to, replace: true };
    }
  }
});

router.afterEach((to) => {
  if (!to.path.includes(REDIRECT_PATH) && NProgress.isStarted()) {
    setTimeout(() => {
      NProgress.done(true);
    }, 200);
  }
});

export default router;
